﻿using System;
using System.Windows.Forms;

using Steema.TeeChart;
using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 캔들 시리즈
        /// </summary>
        private Candle candle = new Candle();

        /// <summary>
        /// 라인 시리즈
        /// </summary>
        private Line line = new Line();

        /// <summary>
        /// 볼륨 시리즈
        /// </summary>
        private Volume volume = new Volume();

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 커스텀 축을 생성한다.

            Axis customAxis = new Axis(this.tChart.Chart);

            customAxis.Horizontal    = false;
            customAxis.StartPosition = 60;
            customAxis.EndPosition   = 100;

            #endregion
            #region 라인 시리즈를 생성한다.

            this.line.DataSource = this.candle;
            this.line.Function   = new AlligatorFunction(this.tChart.Chart);

            #endregion
            #region 볼륨 시리즈를 생성한다.

            this.volume.UseOrigin      = true;
            this.volume.CustomVertAxis = customAxis;
            this.volume.DataSource     = this.candle;
            this.volume.Function       = new GatorFunction(this.tChart.Chart);

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Header.Text           = "Gator Oscillator";
            this.tChart.Legend.Visible        = false;
            this.tChart.Axes.Left.EndPosition = 60;

            this.tChart.Axes.Custom.Add(customAxis);

            this.tChart.Series.Add(candle);
            this.tChart.Series.Add(line);
            this.tChart.Series.Add(volume);

            #endregion

            this.candle.FillSampleValues(200);

            this.refreshButton.Click += refreshButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 갱신하기 버튼 클릭시 처리하기 - refreshButton_Click(sender, e)

        /// <summary>
        /// 갱신하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void refreshButton_Click(object sender, EventArgs e)
        {
            this.candle.FillSampleValues(200);
        }

        #endregion
    }
}